@@ -19,12 +19,10 @@
 #include "projectlocal.h"
 #include "state.h"
 
-#include <kautosavefile.h>
+#include <KAutoSaveFile>
 
-#include <QList>
 #include <QMap>
 #include <QSet>
-#include <QStringList>
 #include <QTimer>
 #include <QVector>
 
