@@ -10,10 +10,9 @@
 #ifndef GETTEXTEXPORTPLUGIN_H
 #define GETTEXTEXPORTPLUGIN_H
 
-#include <catalogfileplugin.h>
+#include "catalogfileplugin.h"
 
-#include <QStringList>
-#include <QTextStream>
+class QTextStream;
 
 namespace GettextCatalog
 {
