@@ -11,12 +11,11 @@
 #define PHASE_H
 
 #include "projectlocal.h"
-#include "version.h"
-
-#include <QDate>
-#include <QString>
 
+class QDate;
+class QString;
 class Catalog;
+
 struct Phase {
     QString name;
     QString process;
