@@ -9,6 +9,7 @@
 
 #include "pos.h"
 #include "catalog.h"
+#include "config-lokalize.h"
 
 bool switchPrev(Catalog *&catalog, DocPosition &pos, int parts)
 {
@@ -93,6 +94,7 @@ bool switchNext(Catalog *&catalog, DocPosition &pos, int parts)
     return true;
 }
 
+#if HAVE_DBUS
 #include <QDBusArgument>
 const QDBusArgument &operator>>(const QDBusArgument &argument, DocPosition &pos)
 {
@@ -123,3 +125,4 @@ QDBusArgument &operator<<(QDBusArgument &argument, const DocPosition &pos)
 
     return argument;
 }
+#endif
