@@ -8,11 +8,14 @@
 
 #include "qamodel.h"
 #include "domroutines.h"
+
+#include <KLocalizedString>
+
 #include <QCoreApplication>
 #include <QFile>
+#include <QRegularExpression>
 #include <QStringList>
 #include <QTextStream>
-#include <klocalizedstring.h>
 
 static const QString ruleTagNames[] = {QStringLiteral("source"), QStringLiteral("falseFriend"), QStringLiteral("target")};
 
